    		Original Mix

    			The rules for originals is the aggregate of
    			the rules that can be found at:
    			"./Originals/Mix"

    		Frontend Originals

    			./Originals/Frontend/Frontend_Rules_Originals.HTML

    		Frontend Modules

    			./Modules/Frontend/frontend_licenses.csv
    			./Modules/Frontend/frontend_licenses_summary.txt

    		Python Modules

    			These rules can be found at:
    			./Modules/Python3/PyPI_rules_entire.json
    			./Modules/Python3/PyPI_rules_legend.txt

    			"ventures", "somatic", "Emergency", "biotech", "body_scan",
    			"botanist", plus "law_dictionary" licenses or rules can be found
    			at those directories.